==> oauth2-authentication-autoconfigure-3.5.6.1-sources.jar: cn/herodotus/engine/oauth2/authentication/autoconfigure/TenantDataSourceAutoConfiguration.java <==
/*
 * Copyright 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Engine licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante Engine 是 Dante Cloud 系统核心组件库，采用 APACHE LICENSE 2.0 开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1. 请不要删除和修改根目录下的LICENSE文件。
 * 2. 请不要删除和修改 Dante Engine 源码头部的版权声明。
 * 3. 请保留源码和相关描述文件的项目出处，作者声明等。
 * 4. 分发源码时候，请注明软件出处 <https://gitee.com/dromara/dante-cloud>
 * 5. 在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/dromara/dante-cloud>
 * 6. 若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.engine.oauth2.authentication.autoconfigure;

import cn.herodotus.engine.data.tenant.condition.ConditionalOnMultiTenant;
import cn.herodotus.engine.data.tenant.enums.MultiTenant;
import jakarta.annotation.PostConstruct;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.context.annotation.ComponentScan;

/**
 * <p>Description: 多租户 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/3/29 21:18
 */
@AutoConfiguration
@ConditionalOnMultiTenant(MultiTenant.DATABASE)
@ComponentScan(basePackages = {
        "cn.herodotus.engine.oauth2.authentication.autoconfigure.tenant",
})
public class TenantDataSourceAutoConfiguration {

    private static final Logger log = LoggerFactory.getLogger(TenantDataSourceAutoConfiguration.class);

    @PostConstruct
    public void postConstruct() {
        log.debug("[Herodotus] |- Auto [Tenant Data Source] Configure.");
    }
}

==> oauth2-authentication-autoconfigure-3.5.7.0-sources.jar: cn/herodotus/engine/oauth2/authentication/autoconfigure/TenantDataSourceAutoConfiguration.java <==
/*
 * Copyright 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Engine licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante Engine 是 Dante Cloud 系统核心组件库，采用 APACHE LICENSE 2.0 开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1. 请不要删除和修改根目录下的LICENSE文件。
 * 2. 请不要删除和修改 Dante Engine 源码头部的版权声明。
 * 3. 请保留源码和相关描述文件的项目出处，作者声明等。
 * 4. 分发源码时候，请注明软件出处 <https://gitee.com/dromara/dante-cloud>
 * 5. 在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/dromara/dante-cloud>
 * 6. 若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.engine.oauth2.authentication.autoconfigure;

import cn.herodotus.engine.data.tenant.condition.ConditionalOnMultiTenant;
import cn.herodotus.engine.data.tenant.enums.MultiTenant;
import jakarta.annotation.PostConstruct;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.context.annotation.ComponentScan;

/**
 * <p>Description: 多租户 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/3/29 21:18
 */
@AutoConfiguration
@ConditionalOnMultiTenant(MultiTenant.DATABASE)
@ComponentScan(basePackages = {
        "cn.herodotus.engine.oauth2.authentication.autoconfigure.tenant",
})
public class TenantDataSourceAutoConfiguration {

    private static final Logger log = LoggerFactory.getLogger(TenantDataSourceAutoConfiguration.class);

    @PostConstruct
    public void postConstruct() {
        log.info("[Herodotus] |- Auto [Tenant Data Source] Configure.");
    }
}
